@@ -78,3 +78,15 @@ def throw(x: Any) -> NoReturn:
     like raise, but can be an expression...
     '''
     raise RuntimeError(x)
+
+
+def reset_hpi_modules() -> None:
+    '''
+    A hack to 'unload' HPI modules, otherwise some modules might cache the config
+    TODO: a bit crap, need a better way..
+    '''
+    import sys
+    import re
+    to_unload = [m for m in sys.modules if re.match(r'my[.]?', m)]
+    for m in to_unload:
+        del sys.modules[m]
