@@ -15,7 +15,7 @@ import pytest # type: ignore
 from pytest import mark # type: ignore
 
 
-from common import tdata
+from common import tdata, reset_hpi_modules
 from config_tests import with_config
 
 from promnesia.common import Visit, Indexer, Loc, Res, DbVisit, _is_windows
@@ -61,7 +61,7 @@ def import_file(p: Union[str, Path], name=None):
     if name is None:
         name = p.stem
     import importlib.util
-    spec = importlib.util.spec_from_file_location(name, p) # type: ignore
+    spec = importlib.util.spec_from_file_location(name, p); assert spec is not None
     foo = importlib.util.module_from_spec(spec)
     with extra_path(p.parent):
         spec.loader.exec_module(foo) # type: ignore
@@ -80,16 +80,15 @@ def assert_got_tzinfo(visits):
 # TODO cache should be in the configuration I suppose?
 
 @pytest.fixture
-def adhoc_config(tmp_path):
-    tdir = Path(tmp_path)
-    cdir = tdir / 'cache'
+def adhoc_config(tmp_path: Path):
+    cdir = tmp_path / 'cache'
     cdir.mkdir()
 
     from promnesia import config
 
     try:
         config.instance = config.Config(
-            OUTPUT_DIR=tdir,
+            OUTPUT_DIR=tmp_path,
             CACHE_DIR=cdir,
         )
         yield
@@ -97,20 +96,6 @@ def adhoc_config(tmp_path):
         config.reset()
 
 
-@pytest.mark.skip(reason='TODO support unpacked directories in HPI')
-def test_takeout_directory(adhoc_config, tmp_path):
-    from my.cfg import config
-    class user_config:
-        takeout_path = tdata('takeout')
-    config.google = user_config # type: ignore
-    import promnesia.sources.takeout as tex
-
-    visits = as_visits(W(tex.index))
-    assert len(visits) > 0 # kinda arbitrary?
-
-    assert_got_tzinfo(visits)
-
-
 def test_with_error() -> None:
     class ExtractionError(Exception):
         pass
@@ -130,14 +115,35 @@ def test_with_error() -> None:
     assert isinstance(v2, DbVisit)
 
 
-def test_takeout_new_zip(adhoc_config) -> None:
+# todo testing this logic probably belongs to hpi or google_takeout_export, but whatever
+def test_takeout_directory(adhoc_config, tmp_path: Path) -> None:
+    reset_hpi_modules()
+    from my.cfg import config
+    class user_config:
+        takeout_path = tdata('takeout')
+    config.google = user_config # type: ignore
+
+    # TODO ugh, the disabled_cachew thing isn't very nice
+    from my.core.cachew import disabled_cachew
+    with disabled_cachew():
+        import promnesia.sources.takeout as tex
+        visits = as_ok_visits(W(tex.index))
+    assert len(visits) == 3
+
+    assert_got_tzinfo(visits)
+
+
+def test_takeout_zip(adhoc_config) -> None:
+    reset_hpi_modules()
     from my.cfg import config
     class user_config:
         takeout_path = tdata('takeout-20150518T000000Z.zip')
     config.google = user_config # type: ignore
 
-    import promnesia.sources.takeout as tex
-    visits = as_ok_visits(tex.index)
+    from my.core.cachew import disabled_cachew
+    with disabled_cachew():
+        import promnesia.sources.takeout as tex
+        visits = as_ok_visits(tex.index)
     assert len(visits) == 3
     [vis] = [v for v in visits if v.norm_url == 'takeout.google.com/settings/takeout']
 
@@ -271,7 +277,7 @@ def test_hook() -> None:
     import promnesia.sources.shellcmd as custom_gen
     from promnesia.__main__ import iter_all_visits
     with with_config('''
-from promnesia import Source
+from promnesia.common import Source
 from promnesia.sources import demo
 
 SOURCES = [
@@ -279,7 +285,7 @@ SOURCES = [
 ]
 
 from typing import Iterable
-from promnesia import DbVisit, Loc, Res
+from promnesia.common import DbVisit, Loc, Res
 
 def HOOK(visit: Res[DbVisit]) -> Iterable[Res[DbVisit]]:
     # NOTE: might be a good idea to check that the visit is an exception first and yield it intact?
